Rebuilding the site
===================

To have the changes show up on the page, you must rebuild the site.

When the site is in need of rebuilding, the menu bar displays an exclamation
mark next to the Rebuild option, the word **Rebuild** also appears in bold.

Clicking on the Rebuild button will initiate a rebuild.  The progress will be
displayed.

If an error occurs, you will see the output.  The error will be displayed
in the Advanced information box.  If you cannot understand and solve the
problem yourself, contact your administrator.

.. admonition:: Permissions

   In order to rebuild the site, you need the “can rebuild site” permission.

